package account

import (
	"net/http"

	"code.nonshy.com/nonshy/website/pkg/config"
	"code.nonshy.com/nonshy/website/pkg/models"
	"code.nonshy.com/nonshy/website/pkg/session"
	"code.nonshy.com/nonshy/website/pkg/templates"
)

// User dashboard or landing page (/me).
func Dashboard() http.HandlerFunc {
	tmpl := templates.Must("account/dashboard.html")
	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
		currentUser, err := session.CurrentUser(r)
		if err != nil {
			http.Error(w, "Couldn't get currentUser", http.StatusInternalServerError)
			return
		}

		// Mark all notifications read?
		if r.FormValue("intent") == "read-notifications" {
			models.MarkNotificationsRead(currentUser)
			session.Flash(w, r, "All of your notifications have been marked as 'read!'")
			templates.Redirect(w, "/me")
			return
		}

		// Get our notifications.
		pager := &models.Pagination{
			Page:    1,
			PerPage: config.PageSizeDashboardNotifications,
			Sort:    "created_at desc",
		}
		pager.ParsePage(r)
		notifs, err := models.PaginateNotifications(currentUser, pager)
		if err != nil {
			session.FlashError(w, r, "Couldn't get your notifications: %s", err)
		}

		// Map our notifications.
		notifMap := models.MapNotifications(notifs)
		models.SetUserRelationshipsInNotifications(currentUser, notifs)

		// Restricted profile warnings.
		var (
			isShyUser    = currentUser.IsShy()
			photoTypes   = currentUser.DistinctPhotoTypes()
			_, hasPublic = photoTypes[models.PhotoPublic]
		)

		var vars = map[string]interface{}{
			"Notifications": notifs,
			"NotifMap":      notifMap,
			"Pager":         pager,

			// Show a warning to 'restricted' profiles who are especially private.
			"IsShyUser":      isShyUser,
			"HasPublicPhoto": hasPublic,
		}
		if err := tmpl.Execute(w, r, vars); err != nil {
			http.Error(w, err.Error(), http.StatusInternalServerError)
			return
		}
	})
}
